@@ -1,7 +1,7 @@
 #
 # coding=utf-8
 """events - Event models for rdial"""
-# Copyright © 2012, 2013  James Rowe <jnrowe@gmail.com>
+# Copyright © 2011-2014  James Rowe <jnrowe@gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,9 +26,9 @@ import glob
 import inspect
 import operator
 import os
-import sys
 import tempfile
 
+from . import compat
 from . import utils
 
 
@@ -207,15 +207,15 @@ class Events(list):
         for task in self.dirty:
             task_file = '%s/%s.csv' % (directory, task)
             events = self.for_task(task)
-            if sys.version_info[0] == 3:
-                temp = tempfile.NamedTemporaryFile(mode='w', newline='',
-                                                   prefix='.', dir=directory,
-                                                   delete=False)
-                writer = csv.DictWriter(temp, FIELDS)
-            else:
+            if compat.PY2:
                 temp = tempfile.NamedTemporaryFile(prefix='.', dir=directory,
                                                    delete=False)
                 writer = csv.DictWriter(temp, FIELDS, lineterminator='\n')
+            else:
+                temp = tempfile.NamedTemporaryFile(mode='w', prefix='.',
+                                                   dir=directory, delete=False)
+                writer = csv.DictWriter(temp, FIELDS, dialect=csv.unix_dialect,
+                                        quoting=csv.QUOTE_MINIMAL)
             # Can't use writeheader, it wasn't added until 2.7.
             writer.writerow(dict(zip(FIELDS, FIELDS)))
             for event in events:
@@ -268,12 +268,12 @@ class Events(list):
         :raise TaskRunningError: An event is already running
 
         """
-        running = self.running()
-        if running:
-            raise TaskRunningError('Running task %s!' % running)
         if not new and task not in self.tasks():
             raise TaskNotExistError("Task %s does not exist!  Use `--new' to "
                                     'create it' % task)
+        running = self.running()
+        if running:
+            raise TaskRunningError('Running task %s!' % running)
         self.append(Event(task, start))
         self.dirty = task
 
